# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class AiAssistantCustomSkillGet(BaseModel):
    """
    AiAssistantCustomSkillGet
    """
    allowed_tools: conlist(StrictStr) = Field(...)
    content: StrictStr = Field(...)
    created_at: StrictInt = Field(...)
    description: StrictStr = Field(...)
    id: StrictInt = Field(...)
    is_active: StrictBool = Field(...)
    last_updated_at: StrictInt = Field(...)
    name: StrictStr = Field(...)
    title: StrictStr = Field(...)
    __properties = ["allowed_tools", "content", "created_at", "description", "id", "is_active", "last_updated_at", "name", "title"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AiAssistantCustomSkillGet:
        """Create an instance of AiAssistantCustomSkillGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AiAssistantCustomSkillGet:
        """Create an instance of AiAssistantCustomSkillGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AiAssistantCustomSkillGet.parse_obj(obj)

        _obj = AiAssistantCustomSkillGet.parse_obj({
            "allowed_tools": obj.get("allowed_tools"),
            "content": obj.get("content"),
            "created_at": obj.get("created_at"),
            "description": obj.get("description"),
            "id": obj.get("id"),
            "is_active": obj.get("is_active"),
            "last_updated_at": obj.get("last_updated_at"),
            "name": obj.get("name"),
            "title": obj.get("title")
        })
        return _obj


